<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'assignfeedback_editpdf', language 'id', version '5.0'.
 *
 * @package     assignfeedback_editpdf
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['addtoquicklist'] = 'Tambahkan ke daftar cepat';
$string['annotationcolour'] = 'Warna anotasi';
$string['black'] = 'Hitam';
$string['blue'] = 'Biru';
$string['cannotopenpdf'] = 'Tidak dapat membuka PDF. Berkas mungkin rusak atau dalam format yang tidak didukung.';
$string['clear'] = 'Bersih';
$string['colourpicker'] = 'Pemilih warna';
$string['command'] = 'Perintah:';
$string['comment'] = 'Komentar';
$string['commentcolour'] = 'Warna komentar';
$string['commentcontextmenu'] = 'Menu konteks komentar';
$string['commentindex'] = 'Indeks komentar';
$string['commentlabel'] = '{$a->pnum}.{$a->cnum}';
$string['couldnotsavepage'] = 'Tidak dapat menyimpan halaman {$a}';
$string['currentstamp'] = 'Stempel';
$string['default'] = 'Diaktifkan sesuai setelan bawaan';
$string['default_help'] = 'Jika disetel, metode umpan balik akan diaktifkan secara bawaan untuk semua penugasan.';
$string['deleteannotation'] = 'Hapus anotasi';
$string['deletecomment'] = 'Hapus komentar';
$string['deletefeedback'] = 'Hapus umpan balik PDF';
$string['downloadablefilename'] = 'umpanbalik.pdf';
$string['downloadfeedback'] = 'Unduh feedback PDF';
$string['draftchangessaved'] = 'Draf anotasi tersimpan';
$string['drag'] = 'Seret';
$string['editpdf'] = 'Anotasi PDF';
$string['editpdf_help'] = 'Beri keterangan pada ajuan siswa langsung di peramban dan buat PDF yang dapat diunduh yang diedit.';
$string['enabled'] = 'Anotasi PDF';
$string['enabled_help'] = 'Jika diaktifkan, pengajar akan dapat membuat berkas PDF beranotasi saat menandai pengiriman tugas. Hal ini memungkinkan pengajar untuk menambahkan komentar, gambar, dan stempel langsung di atas pekerjaan siswa. Anotasi dilakukan di peramban dan tidak diperlukan perangkat lunak tambahan.';
$string['errorgenerateimage'] = 'Galat saat membuat gambar dengan ghostscript, info awakutu: {$a}';
$string['errorpdfpage'] = 'Galat ketika membuat halaman ini.';
$string['expcolcomments'] = 'Luaskan/ciutkan semua komentar';
$string['filter'] = 'Filter komentar ...';
$string['generatefeedback'] = 'Hasilkan PDF umpan balik';
$string['generatingpdf'] = 'Hasilkan PDF umpan balik ...';
$string['gotopage'] = 'Tuju halaman';
$string['green'] = 'Hijau';
$string['gsimage'] = 'Gambar uji Ghostscript';
$string['highlight'] = 'Soroti';
$string['jsrequired'] = 'JavaScript diperlukan untuk membuat anotasi PDF. Harap aktifkan JavaScript di peramban Anda untuk menggunakan fitur ini.';
$string['launcheditor'] = 'Luncurkan editor PDF ...';
$string['line'] = 'Baris';
$string['loadingeditor'] = 'Muat editor PDF ...';
$string['navigatenext'] = 'Halaman selanjutnya (Alt/Shift-Alt/Ctrl-Option + {$a})';
$string['navigateprevious'] = 'Halaman sebelumnya (Alt/Shift-Alt/Ctrl-Option + {$a})';
$string['output'] = 'Keluaran:';
$string['oval'] = 'Oval';
$string['pagenumber'] = 'Halaman {$a}';
$string['pagexofy'] = 'Halaman {$a->page} dari {$a->total}';
$string['partialwarning'] = 'Beberapa berkas dalam pengajuan ini hanya dapat diakses dengan mengunduh langsung.';
$string['pathtogserror'] = 'Jalur yang dikonfigurasi ke ghostscript tidak disetel dengan benar: {$a}';
$string['pathtogspathdesc'] = 'Harap diperhatikan bahwa PDF beranotasi memerlukan letak ghostscript yang disetel di {$a}.';
$string['pen'] = 'Pena';
$string['pluginname'] = 'Anotasi PDF';
$string['preparesubmissionsforannotation'] = 'Siapkan ajuan untuk anotasi';
$string['privacy:metadata:colourpurpose'] = 'Warna komentar atau anotasi';
$string['privacy:metadata:conversionpurpose'] = 'Berkas dikonversi ke PDF untuk anotasi.';
$string['privacy:metadata:filepurpose'] = 'Menyimpan PDF beranotasi dengan umpan balik untuk pengguna.';
$string['privacy:metadata:rawtextpurpose'] = 'Menyimpan teks mentah untuk data cepat.';
$string['privacy:metadata:tablepurpose'] = 'Menyimpan komentar daftar cepat yang ditentukan pengajar';
$string['privacy:metadata:userid'] = 'ID pengguna';
$string['privacy:path'] = 'Umpan balik PDF';
$string['rectangle'] = 'Persegi panjang';
$string['red'] = 'Merah';
$string['result'] = 'Hasil:';
$string['rotateleft'] = 'Putar 90 derajat ke kiri';
$string['rotateright'] = 'Putar 90 derajat ke kanan';
$string['searchcomments'] = 'Telusuri komentar';
$string['select'] = 'Pilih';
$string['stamp'] = 'Stempel';
$string['stamppicker'] = 'Pemilih stempel';
$string['stamps'] = 'Stempel';
$string['stampsdesc'] = 'Stempel harus berupa berkas gambar (ukuran yang disarankan: 40x40). Gambar-gambar ini dapat digunakan dengan alat stempel untuk membuat anotasi PDF.';
$string['test_doesnotexist'] = 'Jalur ghostscript menunjuk ke berkas yang tidak ada';
$string['test_empty'] = 'Jalur ghostscript kosong - masukkan jalur yang benar';
$string['test_isdir'] = 'Jalur ghostscript mengarah ke folder, harap sertakan program ghostscript di jalur yang Anda tentukan';
$string['test_notestfile'] = 'PDF uji hilang';
$string['test_notexecutable'] = 'Ghostscript menunjuk ke berkas yang tidak dapat dieksekusi';
$string['test_ok'] = 'Jalur ghostscript tampaknya OK - harap periksa Anda dapat melihat pesan pada gambar di bawah';
$string['testgs'] = 'Uji jalur ghostscript';
$string['tool'] = 'Perkakas';
$string['toolbarbutton'] = '{$a->tool} {$a->shortcut}';
$string['viewfeedbackonline'] = 'Lihat PDF yang dianotasi...';
$string['white'] = 'Putih';
$string['yellow'] = 'Kuning';
